@@ -4,7 +4,9 @@ test_that("wt_data returns the correct class", {
   skip_on_cran()
 
   prop <- "P846"
-  aa <- wt_data("Mimulus foliatus", property = prop)
+  vcr::use_cassette("wt_data", {
+    aa <- wt_data("Mimulus foliatus", property = prop)
+  }, preserve_exact_body_bytes = TRUE)
 
   expect_is(aa, "list")
   expect_is(aa$labels, "data.frame")
